<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2006 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****

class randomPost {
	const allCatID = 'randomPostAllCat';

	private $post;
	private $blog;
	private $withContent;
	private $categoryRestrict;

	public function __construct(&$blog,$withContent=false,$category=randomPost::allCatID)
	{
		$this->post = null;
		$this->blog =& $blog;
		$this->withContent = $withContent;
		$this->categoryRestrict = $category;
	}

	protected function &getRandomPost($category)
	{
		// Get the total number of public posts in the blog
		if ($category != randomPost::allCatID) {
			$count = $this->blog->getPosts(array('cat_id'=>$category),true);
		} else {
		$count = $this->blog->getPosts(null, true);
		}

		// Get a random number between 0 and the total number of posts minus 1
		// This gives us an offset to access a random record in the next query
		$offset = rand(0, $count->f(0) - 1);

		// Get the random post, via an SQL request of type '... limit 1 offset XXX'
		$params = array('limit'=>array($offset, 1));
		if (!$this->withContent) {
			$params = array_merge($params, array('no_content'=>'1'));
		}
		if ($category != randomPost::allCatID) {
			$params = array_merge($params, array('cat_id'=>$category));
		}
		return $this->blog->getPosts($params);
	}

	protected function initRandomPost()
	{
		if ($this->post == null) {
			$this->post =& $this->getRandomPost($this->categoryRestrict);
		}
	}

	public function getPostURL()
	{
		$this->initRandomPost();
		return $this->post->getURL();
	}

	public function getPostTitle()
	{
		$this->initRandomPost();
		return $this->post->post_title;
	}

	public function &getPost()
	{
		$this->initRandomPost();
		return $this->post;
	}

}
?>
